@@ -280,6 +280,15 @@ fields:
     tio_field: plugin.cvss3_temporal_score
     tsc_field: cvssV3TemporalScore
 
+  - jira_field: Patch Publication Date
+    type: readonlyfield
+    searcher: textsearcher
+    issuetype:
+      - Task
+      - Sub-task
+    tio_field: plugin.patch_publication_date
+    tsc_field: patchPubDate
+
   - jira_field: Tenable Plugin ID
     type: readonlyfield
     searcher: textsearcher
@@ -382,7 +391,7 @@ fields:
     searcher: datetimerange
     issue_type:
       - Sub-task
-    tio_field: first_seen
+    tio_field: first_found
     tsc_field: firstSeen
 
   - jira_field: Vulnerability Last Seen
@@ -390,7 +399,7 @@ fields:
     searcher: datetimerange
     issue_type:
       - Sub-task
-    tio_field: last_seen
+    tio_field: last_found
     tsc_field: lastSeen
 
   - jira_field: Vulnerability Last Fixed
