@@ -404,16 +404,22 @@ class Tio2Jira:
             v = flatten(vulnitem)
 
             # if the tio_ignore_accepted flag is set to True, then will will
-            # ignore the vulnerability, log the ignore, and move on.
+            # either ignore the vulnerability, or process the vulnerability as
+            # a closed vuln.
             if (self.config['tenable'].get('tio_ignore_accepted', False)
               and v.get('severity_modification_type', '').lower() == 'accepted'):
-                self._log.info(
-                    'Skipping {} on {} as it\'s an accepted risk'.format(
-                        v.get('plugin.id'), v.get('asset.uuid')))
-                continue
-
-            # send the vulnerability instance to processing.
-            self._process_open_vuln(v, fid)
+                if self.config['tenable'].get('tio_autoclose_accepted', False):
+                    self._log.info(
+                        'Autoclosing {} on {} as it\'s and accepted risk'.format(
+                            v.get('plugin.id'), v.get('asset.uuid')))
+                    self._process_closed_vuln(v, fid)
+                else:
+                    self._log.info(
+                        'Skipping {} on {} as it\'s an accepted risk'.format(
+                            v.get('plugin.id'), v.get('asset.uuid')))
+            else:
+                # send the vulnerability instance to processing.
+                self._process_open_vuln(v, fid)
 
     def close_issues(self, vulns):
         '''
@@ -453,10 +459,15 @@ class Tio2Jira:
             # generate a an export for the open and reopened vulns that match
             # the criticality rating described.  Then pass the export iterator
             # to the create_issues method.
+            vpr = None
+            if self.config['tenable'].get('tio_vpr_thresh'):
+                vpr = {'gte': self.config['tenable'].get('tio_vpr_thresh')}
             vulns = self._src.exports.vulns(
                 last_found=observed_since,
                 severity=self.config['tenable']['tio_severities'],
-                num_assets=self.config['tenable'].get('chunk_size', 1000))
+                num_assets=self.config['tenable'].get('chunk_size', 1000),
+                vpr=vpr,
+            )
             self.create_issues(vulns)
 
             # generate a an export for the fixed vulns that match the
